# Plugins - Integrate Text-to-speech Feature

You may write a plugin with integration text-to-speech feature.

For example,

```
from letmedoit.utils.tts_utils import TTSUtil
TTSUtil.play("Hello!")
TTSUtil.play("你好！", "zh")
```

Read our plugin "pronunce words" at

https://github.com/eliranwong/letmedoit/blob/main/package/letmedoit/plugins/pronounce%20words.py

# More about LetMeDoIt AI Plugins

https://github.com/eliranwong/letmedoit/wiki/Plugins-%E2%80%90-Overview